@@ -1,15 +1,14 @@
-from torch_simivec import SimiLossW2V
+from torch_simivec import SimiLoss
 import torch
 import numpy as np
 
 
 def test1():
     # init model
-    model = SimiLossW2V(
-        vocab_size=10,
-        embed_size=300,
-        context_size=4,
-        use_kernel=None
+    model = SimiLoss(
+        tokenlist_size=10,
+        embedding_size=300,
+        context_size=4
     )
     # create a positive & negative example
     X_pos = torch.tensor([[[0, 2, 9], [6, 0, 8], [1, 3, 4], [7, 8, 9]]])
@@ -18,5 +17,5 @@ def test1():
     X_neg = torch.tensor(np.random.permutation(X_pos))
     y_neg = torch.tensor(np.random.permutation(y_pos))
     # compute loss
-    loss = model(y_pos, X_pos, y_neg, X_neg, regul=False)
+    loss = model(y_pos, X_pos, y_neg, X_neg)
     assert torch.abs(loss - 0.0) < 1e-5
